@@ -126,17 +126,16 @@ try:
 
         Requires the name of the menu and type of the menu
         '''
-        from ..context_menu.windows_menus import remove_windows_menu
 
         if platform.system() == 'Linux':
-            linux_menus.NautilusMenu(self.name, [ContextCommand(
-                self.name, command=self.command, python=self.python)], self.type).compile()
+            linux_menus.remove_linux_menu(name)
         if platform.system() == 'Windows':
-            remove_windows_menu(name, type)
+            windows_menus.remove_windows_menu(name, type)
 
 
     removeMenu('Foo menu', 'FILES')
 
-except:
+except Exception as e:
     # For testing
+    print(e)
     pass
